@@ -96,7 +96,6 @@ gpm_cell_array_get_unit (GpmCellArray *cell_array)
 {
 	GpmCellUnit *unit;
 
-	g_return_val_if_fail (cell_array != NULL, NULL);
 	g_return_val_if_fail (GPM_IS_CELL_ARRAY (cell_array), NULL);
 
 	unit = &(cell_array->priv->unit);
@@ -110,7 +109,6 @@ gpm_cell_array_get_unit (GpmCellArray *cell_array)
 guint
 gpm_cell_array_get_num_cells (GpmCellArray *cell_array)
 {
-	g_return_val_if_fail (cell_array != NULL, 0);
 	g_return_val_if_fail (GPM_IS_CELL_ARRAY (cell_array), 0);
 
 	return cell_array->priv->array->len;
@@ -124,7 +122,6 @@ gpm_cell_array_get_icon (GpmCellArray *cell_array)
 {
 	GpmCellUnit *unit;
 
-	g_return_val_if_fail (cell_array != NULL, 0);
 	g_return_val_if_fail (GPM_IS_CELL_ARRAY (cell_array), 0);
 
 	unit = &(cell_array->priv->unit);
@@ -139,7 +136,6 @@ gpm_cell_array_get_kind (GpmCellArray *cell_array)
 {
 	GpmCellUnit *unit;
 
-	g_return_val_if_fail (cell_array != NULL, 0);
 	g_return_val_if_fail (GPM_IS_CELL_ARRAY (cell_array), 0);
 
 	unit = &(cell_array->priv->unit);
@@ -154,7 +150,6 @@ gpm_cell_array_get_cell (GpmCellArray *cell_array, guint id)
 {
 	GpmCell *cell;
 
-	g_return_val_if_fail (cell_array != NULL, NULL);
 	g_return_val_if_fail (GPM_IS_CELL_ARRAY (cell_array), NULL);
 
 	if (id > cell_array->priv->array->len) {
@@ -178,12 +173,14 @@ gpm_cell_array_get_time_until_action (GpmCellArray *cell_array)
 	guint action_time;
 	gint difference;
 
+	g_return_val_if_fail (GPM_IS_CELL_ARRAY (cell_array), 0);
+
 	/* clear old values (except previous charge rate) */
 	unit = &(cell_array->priv->unit);
 	gpm_cell_unit_init (unit);
 
 	/* not valid */
-	if (unit->is_charging == TRUE || unit->is_discharging == FALSE) {
+	if (unit->is_charging || unit->is_discharging == FALSE) {
 		return 0;
 	}
 
@@ -194,7 +191,7 @@ gpm_cell_array_get_time_until_action (GpmCellArray *cell_array)
 
 	/* calculate! */
 	gpm_conf_get_bool (cell_array->priv->conf, GPM_CONF_USE_TIME_POLICY, &use_time_primary);
-	if (use_time_primary == TRUE) {
+	if (use_time_primary) {
 		/* simple subtraction */
 		gpm_conf_get_uint (cell_array->priv->conf, GPM_CONF_THRESH_TIME_ACTION, &action_time);
 		difference = (gint) unit->time_discharge - (gint) action_time;
@@ -222,6 +219,8 @@ gpm_cell_array_get_time_until_action (GpmCellArray *cell_array)
 static void
 gpm_cell_perhaps_recall_cb (GpmCell *cell, gchar *oem_vendor, gchar *website, GpmCellArray *cell_array)
 {
+	g_return_if_fail (GPM_IS_CELL_ARRAY (cell_array));
+
 	/* only emit this once per startup */
 	if (cell_array->priv->done_recall == FALSE) {
 		/* just proxy it to the engine layer */
@@ -237,6 +236,8 @@ gpm_cell_perhaps_recall_cb (GpmCell *cell, gchar *oem_vendor, gchar *website, Gp
 static void
 gpm_cell_low_capacity_cb (GpmCell *cell, guint capacity, GpmCellArray *cell_array)
 {
+	g_return_if_fail (GPM_IS_CELL_ARRAY (cell_array));
+
 	/* only emit this once per startup */
 	if (cell_array->priv->done_capacity == FALSE) {
 		/* just proxy it to the GUI layer */
@@ -266,6 +267,8 @@ gpm_cell_array_update (GpmCellArray *cell_array)
 	guint length;
 	guint i;
 
+	g_return_val_if_fail (GPM_IS_CELL_ARRAY (cell_array), FALSE);
+
 	/* clear old values (except previous charge rate) */
 	unit = &(cell_array->priv->unit);
 	gpm_cell_unit_init (unit);
@@ -296,11 +299,11 @@ gpm_cell_array_update (GpmCellArray *cell_array)
 		 * be present. */
 		unit->is_present = TRUE;
 
-		if (unit_temp->is_charging == TRUE) {
+		if (unit_temp->is_charging) {
 			unit->is_charging = TRUE;
 		}
 
-		if (unit_temp->is_discharging == TRUE) {
+		if (unit_temp->is_discharging) {
 			unit->is_discharging = TRUE;
 			num_discharging++;
 		}
@@ -341,7 +344,7 @@ gpm_cell_array_update (GpmCellArray *cell_array)
 	}
 
 	/* sanity check */
-	if (unit->is_discharging == TRUE && unit->is_charging == TRUE) {
+	if (unit->is_discharging && unit->is_charging == TRUE) {
 		gpm_warning ("Sanity check kicked in! "
 			     "Multiple device object cannot be charging and discharging simultaneously!");
 		unit->is_charging = FALSE;
@@ -354,14 +357,14 @@ gpm_cell_array_update (GpmCellArray *cell_array)
 	 * a very high charge. Fixes bug #327471 */
 	if (unit->kind == GPM_CELL_UNIT_KIND_PRIMARY &&
 	    unit->charge_current > 0 && unit->charge_last_full > 0) {
-		gint pc = 100 * ((gfloat)unit->charge_current /
+		gfloat pc = 100.0f * ((gfloat)unit->charge_current /
 				(gfloat)unit->charge_last_full);
-		if (pc < 0) {
+		if (pc < 0.0f) {
 			gpm_warning ("Corrected percentage charge (%i) and set to minimum", pc);
-			pc = 0;
-		} else if (pc > 100) {
+			pc = 0.0f;
+		} else if (pc > 100.0f) {
 			gpm_warning ("Corrected percentage charge (%i) and set to maximum", pc);
-			pc = 100;
+			pc = 100.0f;
 		}
 		unit->percentage = pc;
 	}
@@ -373,7 +376,7 @@ gpm_cell_array_update (GpmCellArray *cell_array)
 	if (unit->kind == GPM_CELL_UNIT_KIND_PRIMARY &&
 	    unit->is_charging == FALSE &&
 	    unit->is_discharging == FALSE &&
-	    unit->percentage > 0 &&
+	    unit->percentage > 0.0f &&
 	    unit->percentage < GPM_CELL_UNIT_MIN_CHARGED_PERCENTAGE) {
 		gboolean on_ac;
 
@@ -381,7 +384,7 @@ gpm_cell_array_update (GpmCellArray *cell_array)
 		on_ac = gpm_ac_adapter_is_present (cell_array->priv->ac_adapter);
 		gpm_debug ("Battery is neither charging nor discharging, "
 			   "using ac_adaptor value %i", on_ac);
-		if (on_ac == TRUE) {
+		if (on_ac) {
 			unit->is_charging = TRUE;
 			unit->is_discharging = FALSE;
 		} else {
@@ -392,19 +395,19 @@ gpm_cell_array_update (GpmCellArray *cell_array)
 
 	/* We may want to use the old time remaining code.
 	 * Hopefully we can remove this in 2.19.x sometime. */
-	if (cell_array->priv->use_profile_calc == TRUE &&
+	if (cell_array->priv->use_profile_calc &&
 	    unit->kind == GPM_CELL_UNIT_KIND_PRIMARY) {
-		gpm_debug ("unit->percentage = %i", unit->percentage);
+		gpm_debug ("unit->percentage = %.1f", unit->percentage);
 		unit->time_discharge = gpm_profile_get_time (cell_array->priv->profile, unit->percentage, TRUE);
 		unit->time_charge = gpm_profile_get_time (cell_array->priv->profile, unit->percentage, FALSE);
 	} else {
 		/* We only do the "better" remaining time algorithm if the battery has rate,
 		 * i.e not a UPS, which gives it's own battery.time_charge but has no rate */
 		if (unit->rate > 0) {
-			if (unit->is_discharging == TRUE) {
+			if (unit->is_discharging) {
 				unit->time_discharge = 3600 * ((float)unit->charge_current /
 								      (float)unit->rate);
-			} else if (unit->is_charging == TRUE) {
+			} else if (unit->is_charging) {
 				unit->time_charge = 3600 *
 					((float)(unit->charge_last_full - unit->charge_current) /
 					(float)unit->rate);
@@ -444,6 +447,8 @@ gpm_cell_array_get_config_id (GpmCellArray *cell_array)
 	guint length;
 	guint i;
 
+	g_return_val_if_fail (GPM_IS_CELL_ARRAY (cell_array), NULL);
+
 	unit = &(cell_array->priv->unit);
 
 	/* invalid if not primary */
@@ -488,6 +493,8 @@ gpm_cell_array_emit_system_action (GpmCellArray	   *cell_array,
 	gfloat accuracy;
 	GpmCellUnit *unit;
 
+	g_return_val_if_fail (GPM_IS_CELL_ARRAY (cell_array), FALSE);
+
 	/* do we trust the profile enough to make a decision? */
 	unit = &(cell_array->priv->unit);
 	if (unit->kind == GPM_CELL_UNIT_KIND_PRIMARY) {
@@ -525,6 +532,8 @@ gpm_cell_array_percent_changed (GpmCellArray *cell_array)
 	GpmWarningsState warnings_state;
 	GpmCellUnit *unit;
 
+	g_return_if_fail (GPM_IS_CELL_ARRAY (cell_array));
+
 	unit = &(cell_array->priv->unit);
 
 	gpm_debug ("printing combined new device:");
@@ -532,7 +541,7 @@ gpm_cell_array_percent_changed (GpmCellArray *cell_array)
 
 	/* only emit if all devices are fully charged */
 	if (cell_array->priv->done_fully_charged == FALSE &&
-	    gpm_cell_unit_is_charged (unit) == TRUE) {
+	    gpm_cell_unit_is_charged (unit)) {
 		gpm_debug ("** EMIT: fully-charged");
 		g_signal_emit (cell_array, signals [FULLY_CHARGED], 0);
 		cell_array->priv->done_fully_charged = TRUE;
@@ -541,7 +550,7 @@ gpm_cell_array_percent_changed (GpmCellArray *cell_array)
 	/* We only re-enable the fully charged notification when the battery
 	   drops down to 95% as some batteries charge to 100% and then fluctuate
 	   from ~98% to 100%. See #338281 for details */
-	if (cell_array->priv->done_fully_charged == TRUE &&
+	if (cell_array->priv->done_fully_charged &&
 	    unit->percentage < GPM_CELL_UNIT_MIN_CHARGED_PERCENTAGE &&
 	    gpm_cell_unit_is_charged (unit) == FALSE) {
 		gpm_debug ("enabled fully charged");
@@ -549,7 +558,7 @@ gpm_cell_array_percent_changed (GpmCellArray *cell_array)
 	}
 
 	/* only get a warning state if we are discharging */
-	if (unit->is_discharging == TRUE) {
+	if (unit->is_discharging) {
 		warnings_state = gpm_warnings_get_state (cell_array->priv->warnings, unit);
 	} else {
 		warnings_state = GPM_WARNINGS_NONE;
@@ -583,10 +592,12 @@ gpm_cell_array_percent_changed (GpmCellArray *cell_array)
  * gpm_cell_percent_changed_cb:
  */
 static void
-gpm_cell_percent_changed_cb (GpmCell *cell, guint percent, GpmCellArray *cell_array)
+gpm_cell_percent_changed_cb (GpmCell *cell, gfloat percent, GpmCellArray *cell_array)
 {
 	GpmCellUnit *unit;
-	guint old_percent;
+	gfloat old_percent;
+
+	g_return_if_fail (GPM_IS_CELL_ARRAY (cell_array));
 
 	unit = &(cell_array->priv->unit);
 
@@ -598,7 +609,7 @@ gpm_cell_percent_changed_cb (GpmCell *cell, guint percent, GpmCellArray *cell_ar
 
 	/* provide data if we are primary. Will need profile if multibattery */
 	if (unit->kind == GPM_CELL_UNIT_KIND_PRIMARY) {
-		gpm_profile_register_percentage (cell_array->priv->profile, percent);
+		gpm_profile_register_percentage (cell_array->priv->profile, (guint) percent);
 	}
 
 	/* proxy to engine if different */
@@ -617,6 +628,8 @@ gpm_cell_charging_changed_cb (GpmCell *cell, gboolean charging, GpmCellArray *ce
 {
 	GpmCellUnit *unit;
 
+	g_return_if_fail (GPM_IS_CELL_ARRAY (cell_array));
+
 	unit = &(cell_array->priv->unit);
 
 	/* recalculate */
@@ -626,7 +639,7 @@ gpm_cell_charging_changed_cb (GpmCell *cell, gboolean charging, GpmCellArray *ce
 	gpm_cell_unit_print (unit);
 
 	/* invalidate warning */
-	if (unit->is_discharging == FALSE || unit->is_charging == TRUE) {
+	if (unit->is_discharging == FALSE || unit->is_charging) {
 		gpm_debug ("warning state invalidated");
 		cell_array->priv->warnings_state = GPM_WARNINGS_NONE;
 	}
@@ -649,6 +662,8 @@ gpm_cell_discharging_changed_cb (GpmCell *cell, gboolean discharging, GpmCellArr
 {
 	GpmCellUnit *unit;
 
+	g_return_if_fail (GPM_IS_CELL_ARRAY (cell_array));
+
 	unit = &(cell_array->priv->unit);
 
 	/* recalculate */
@@ -658,7 +673,7 @@ gpm_cell_discharging_changed_cb (GpmCell *cell, gboolean discharging, GpmCellArr
 	gpm_cell_unit_print (unit);
 
 	/* invalidate warning */
-	if (unit->is_discharging == FALSE || unit->is_charging == TRUE) {
+	if (unit->is_discharging == FALSE || unit->is_charging) {
 		cell_array->priv->warnings_state = GPM_WARNINGS_NONE;
 	}
 
@@ -668,24 +683,26 @@ gpm_cell_discharging_changed_cb (GpmCell *cell, gboolean discharging, GpmCellArr
 }
 
 /**
- * gpm_cell_array_index_udi:
+ * gpm_cell_array_index_device_id:
  *
  * Returns -1 if not found
  */
 static gint
-gpm_cell_array_index_udi (GpmCellArray *cell_array, const gchar *udi)
+gpm_cell_array_index_device_id (GpmCellArray *cell_array, const gchar *device_id)
 {
 	gint i;
 	guint length;
-	const gchar *cell_udi;
+	const gchar *cell_device_id;
 	GpmCell *cell;
 
+	g_return_val_if_fail (GPM_IS_CELL_ARRAY (cell_array), 0);
+
 	length = cell_array->priv->array->len;
 	for (i=0;i<length;i++) {
 		cell = (GpmCell *) g_ptr_array_index (cell_array->priv->array, i);
-		cell_udi = gpm_cell_get_udi (cell);
-		if (cell_udi != NULL && strcmp (cell_udi, udi) == 0) {
-			gpm_debug ("Found %s with udi check", udi);
+		cell_device_id = gpm_cell_get_device_id (cell);
+		if (cell_device_id != NULL && strcmp (cell_device_id, device_id) == 0) {
+			gpm_debug ("Found %s with device id check", device_id);
 			return i;
 		}
 	}
@@ -704,16 +721,18 @@ gpm_check_device_key (GpmCellArray *cell_array, const gchar *udi, const gchar *k
 	gboolean matches = FALSE;
 	gchar *rettype;
 
+	g_return_val_if_fail (GPM_IS_CELL_ARRAY (cell_array), FALSE);
+
 	device = hal_gdevice_new ();
 	ret = hal_gdevice_set_udi (device, udi);
-	if (ret == FALSE) {
+	if (!ret) {
 		gpm_warning ("failed to set UDI %s", udi);
 		return FALSE;
 	}
 
 	/* check type */
 	ret = hal_gdevice_get_string (device, key, &rettype, NULL);
-	if (ret == FALSE || rettype == NULL) {
+	if (!ret || rettype == NULL) {
 		gpm_warning ("failed to get %s", key);
 		return FALSE;
 	}
@@ -738,6 +757,8 @@ gpm_cell_array_collection_changed (GpmCellArray *cell_array)
 	gchar *config_id;
 	guint length;
 
+	g_return_val_if_fail (GPM_IS_CELL_ARRAY (cell_array), FALSE);
+
 	length = cell_array->priv->array->len;
 	/* if we have no devices, don't try to get refresh anything */
 	if (length == 0) {
@@ -768,10 +789,10 @@ gpm_cell_array_collection_changed (GpmCellArray *cell_array)
 }
 
 /**
- * gpm_cell_array_add_hal_udi:
+ * gpm_cell_array_add_device_id:
  */
 static gboolean
-gpm_cell_array_add_hal_udi (GpmCellArray *cell_array, const gchar *udi)
+gpm_cell_array_add_device_id (GpmCellArray *cell_array, const gchar *device_id)
 {
 	GpmCell *cell;
 	GpmCellUnit *unit;
@@ -779,21 +800,23 @@ gpm_cell_array_add_hal_udi (GpmCellArray *cell_array, const gchar *udi)
 	const gchar *kind_string;
 	gboolean ret;
 
+	g_return_val_if_fail (GPM_IS_CELL_ARRAY (cell_array), FALSE);
+
 	unit = &(cell_array->priv->unit);
 
 	/* check type */
 	kind_string = gpm_cell_unit_get_kind_string (unit);
-	ret = gpm_check_device_key (cell_array, udi, "battery.type", kind_string);
-	if (ret == FALSE) {
-		gpm_debug ("not adding %s for %s", udi, kind_string);
+	ret = gpm_check_device_key (cell_array, device_id, "battery.type", kind_string);
+	if (!ret) {
+		gpm_debug ("not adding %s for %s", device_id, kind_string);
 		return FALSE;
 	}
 
-	/* is this UDI in our array? */
-	index = gpm_cell_array_index_udi (cell_array, udi);
+	/* is this device id in our array? */
+	index = gpm_cell_array_index_device_id (cell_array, device_id);
 	if (index != -1) {
 		/* already added */
-		gpm_debug ("already added %s", udi);
+		gpm_debug ("already added %s", device_id);
 		return FALSE;
 	}
 
@@ -810,7 +833,7 @@ gpm_cell_array_add_hal_udi (GpmCellArray *cell_array, const gchar *udi)
 			  G_CALLBACK (gpm_cell_charging_changed_cb), cell_array);
 	g_signal_connect (cell, "discharging-changed",
 			  G_CALLBACK (gpm_cell_discharging_changed_cb), cell_array);
-	gpm_cell_set_hal_udi (cell, udi);
+	gpm_cell_set_device_id (cell, device_id);
 	gpm_cell_print (cell);
 
 	g_ptr_array_add (cell_array->priv->array, (gpointer) cell);
@@ -833,6 +856,8 @@ gpm_cell_array_coldplug (GpmCellArray *cell_array)
 	gboolean ret;
 	GpmCellUnit *unit;
 
+	g_return_val_if_fail (GPM_IS_CELL_ARRAY (cell_array), FALSE);
+
 	unit = &(cell_array->priv->unit);
 
 	/* we treat phones as hotpluggable devices only */
@@ -844,7 +869,7 @@ gpm_cell_array_coldplug (GpmCellArray *cell_array)
 	/* get all the hal devices of this type */
 	error = NULL;
 	ret = hal_gmanager_find_capability (cell_array->priv->hal_manager, "battery", &device_names, &error);
-	if (ret == FALSE) {
+	if (!ret) {
 		gpm_warning ("Couldn't obtain list of batteries: %s", error->message);
 		g_error_free (error);
 		return FALSE;
@@ -852,7 +877,7 @@ gpm_cell_array_coldplug (GpmCellArray *cell_array)
 
 	/* Try to add all, the add will fail for batteries not of the correct type */
 	for (i=0; device_names[i]; i++) {
-		gpm_cell_array_add_hal_udi (cell_array, device_names[i]);
+		gpm_cell_array_add_device_id (cell_array, device_names[i]);
 	}
 
 	hal_gmanager_free_capability (device_names);
@@ -867,7 +892,6 @@ gpm_cell_array_set_type (GpmCellArray *cell_array, GpmCellUnitKind kind)
 {
 	GpmCellUnit *unit;
 
-	g_return_val_if_fail (cell_array != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_CELL_ARRAY (cell_array), FALSE);
 
 	unit = &(cell_array->priv->unit);
@@ -894,6 +918,8 @@ gpm_cell_array_free (GpmCellArray *cell_array)
 	guint length;
 	guint i;
 
+	g_return_if_fail (GPM_IS_CELL_ARRAY (cell_array));
+
 	length = cell_array->priv->array->len;
 	/* iterate thru all the devices to free */
 	for (i=0;i<length;i++) {
@@ -913,7 +939,6 @@ gpm_cell_array_free (GpmCellArray *cell_array)
 gboolean
 gpm_cell_array_refresh (GpmCellArray *cell_array)
 {
-	g_return_val_if_fail (cell_array != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_CELL_ARRAY (cell_array), FALSE);
 
 	/* free all, then re-coldplug */
@@ -939,7 +964,6 @@ gpm_cell_array_get_description (GpmCellArray *cell_array)
 	GpmCellUnit *unit;
 	gboolean plural = FALSE;
 
-	g_return_val_if_fail (cell_array != NULL, NULL);
 	g_return_val_if_fail (GPM_IS_CELL_ARRAY (cell_array), NULL);
 
 	unit = &(cell_array->priv->unit);
@@ -958,19 +982,19 @@ gpm_cell_array_get_description (GpmCellArray *cell_array)
 	if (unit->kind == GPM_CELL_UNIT_KIND_MOUSE ||
 	    unit->kind == GPM_CELL_UNIT_KIND_KEYBOARD ||
 	    unit->kind == GPM_CELL_UNIT_KIND_PDA) {
-		return g_strdup_printf ("%s (%i%%)\n", type_desc, unit->percentage);
+		return g_strdup_printf ("%s (%.1f%%)\n", type_desc, unit->percentage);
 	}
 
 	/* we care if we are on AC */
 	if (unit->kind == GPM_CELL_UNIT_KIND_PHONE) {
-		if (unit->is_charging == TRUE || unit->is_discharging == FALSE) {
-			return g_strdup_printf ("%s charging (%i%%)\n", type_desc, unit->percentage);
+		if (unit->is_charging || unit->is_discharging == FALSE) {
+			return g_strdup_printf ("%s charging (%.1f%%)\n", type_desc, unit->percentage);
 		}
-		return g_strdup_printf ("%s (%i%%)\n", type_desc, unit->percentage);
+		return g_strdup_printf ("%s (%.1f%%)\n", type_desc, unit->percentage);
 	}
 
 	/* don't display the text if we are low in accuracy */
-	accuracy = gpm_profile_get_accuracy (cell_array->priv->profile, unit->percentage);
+	accuracy = gpm_profile_get_accuracy (cell_array->priv->profile, (guint) unit->percentage);
 	gpm_debug ("accuracy = %i", accuracy);
 
 	/* precalculate so we don't get Unknown time remaining */
@@ -980,35 +1004,35 @@ gpm_cell_array_get_description (GpmCellArray *cell_array)
 	/* We always display "Laptop battery 16 minutes remaining" as we need
 	   to clarify what device we are refering to. For details see :
 	   http://bugzilla.gnome.org/show_bug.cgi?id=329027 */
-	if (gpm_cell_unit_is_charged (unit) == TRUE) {
+	if (gpm_cell_unit_is_charged (unit)) {
 
 		if (unit->kind == GPM_CELL_UNIT_KIND_PRIMARY &&
 		    accuracy > GPM_CELL_ARRAY_TEXT_MIN_ACCURACY) {
-			time = gpm_profile_get_time (cell_array->priv->profile, unit->percentage, TRUE);
+			time = gpm_profile_get_time (cell_array->priv->profile, (guint) unit->percentage, TRUE);
 			discharge_time_round = gpm_precision_round_down (time, GPM_UI_TIME_PRECISION);
 			discharge_timestring = gpm_get_timestring (discharge_time_round);
-			description = g_strdup_printf (_("%s fully charged (%i%%)\nProvides %s battery runtime\n"),
+			description = g_strdup_printf (_("%s fully charged (%.1f%%)\nProvides %s battery runtime\n"),
 							type_desc, unit->percentage, discharge_timestring);
 			g_free (discharge_timestring);
 		} else {
-			description = g_strdup_printf (_("%s fully charged (%i%%)\n"),
+			description = g_strdup_printf (_("%s fully charged (%.1f%%)\n"),
 							type_desc, unit->percentage);
 		}
 
-	} else if (unit->is_discharging == TRUE) {
+	} else if (unit->is_discharging) {
 
 		if (discharge_time_round > GPM_CELL_ARRAY_TEXT_MIN_TIME) {
 			discharge_timestring = gpm_get_timestring (discharge_time_round);
-			description = g_strdup_printf (_("%s %s remaining (%i%%)\n"),
+			description = g_strdup_printf (_("%s %s remaining (%.1f%%)\n"),
 						type_desc, discharge_timestring, unit->percentage);
 			g_free (discharge_timestring);
 		} else {
 			/* don't display "Unknown remaining" */
-			description = g_strdup_printf (_("%s discharging (%i%%)\n"),
+			description = g_strdup_printf (_("%s discharging (%.1f%%)\n"),
 						type_desc, unit->percentage);
 		}
 
-	} else if (unit->is_charging == TRUE) {
+	} else if (unit->is_charging) {
 
 		if (charge_time_round > GPM_CELL_ARRAY_TEXT_MIN_TIME &&
 		    discharge_time_round > GPM_CELL_ARRAY_TEXT_MIN_TIME &&
@@ -1016,19 +1040,19 @@ gpm_cell_array_get_description (GpmCellArray *cell_array)
 			/* display both discharge and charge time */
 			charge_timestring = gpm_get_timestring (charge_time_round);
 			discharge_timestring = gpm_get_timestring (discharge_time_round);
-			description = g_strdup_printf (_("%s %s until charged (%i%%)\nProvides %s battery runtime\n"),
+			description = g_strdup_printf (_("%s %s until charged (%.1f%%)\nProvides %s battery runtime\n"),
 							type_desc, charge_timestring, unit->percentage, discharge_timestring);
 			g_free (charge_timestring);
 			g_free (discharge_timestring);
 		} else if (charge_time_round > GPM_CELL_ARRAY_TEXT_MIN_TIME) {
 			/* display only charge time */
 			charge_timestring = gpm_get_timestring (charge_time_round);
-			description = g_strdup_printf (_("%s %s until charged (%i%%)\n"),
+			description = g_strdup_printf (_("%s %s until charged (%.1f%%)\n"),
 						type_desc, charge_timestring, unit->percentage);
 			g_free (charge_timestring);
 		} else {
 			/* don't display "Unknown remaining" */
-			description = g_strdup_printf (_("%s charging (%i%%)\n"),
+			description = g_strdup_printf (_("%s charging (%.1f%%)\n"),
 						type_desc, unit->percentage);
 		}
 
@@ -1055,8 +1079,10 @@ hal_device_removed_cb (HalGManager  *hal_manager,
 	gint index;
 	GpmCell *cell;
 
+	g_return_val_if_fail (GPM_IS_CELL_ARRAY (cell_array), FALSE);
+
 	/* is this UDI in our array? */
-	index = gpm_cell_array_index_udi (cell_array, udi);
+	index = gpm_cell_array_index_device_id (cell_array, udi);
 	if (index == -1) {
 		/* nope */
 		return FALSE;
@@ -1094,7 +1120,7 @@ hal_new_capability_cb (HalGManager  *hal_manager,
 	gpm_debug ("udi=%s, capability=%s", udi, capability);
 
 	if (strcmp (capability, "battery") == 0) {
-		gpm_cell_array_add_hal_udi (cell_array, udi);
+		gpm_cell_array_add_device_id (cell_array, udi);
 	}
 }
 
@@ -1126,8 +1152,8 @@ hal_device_added_cb (HalGManager  *hal_manager,
 	}
 
 	/* if a battery, then add */
-	if (is_battery == TRUE) {
-		gpm_cell_array_add_hal_udi (cell_array, udi);
+	if (is_battery) {
+		gpm_cell_array_add_device_id (cell_array, udi);
 	}
 	g_object_unref (device);
 }
@@ -1278,8 +1304,8 @@ gpm_cell_array_class_init (GpmCellArrayClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GpmCellArrayClass, percent_changed),
 			      NULL, NULL,
-			      g_cclosure_marshal_VOID__UINT,
-			      G_TYPE_NONE, 1, G_TYPE_UINT);
+			      g_cclosure_marshal_VOID__FLOAT,
+			      G_TYPE_NONE, 1, G_TYPE_FLOAT);
 	signals [CHARGING_CHANGED] =
 		g_signal_new ("charging-changed",
 			      G_TYPE_FROM_CLASS (object_class),
@@ -1495,7 +1521,7 @@ gpm_st_cell_array (GpmSelfTest *test)
 	/************************************************************/
 	gpm_st_title (test, "make sure we get set type");
 	ret = gpm_cell_array_set_type (cell_array, GPM_CELL_UNIT_KIND_PRIMARY);
-	if (ret == TRUE) {
+	if (ret) {
 		gpm_st_success (test, "set type");
 	} else {
 		gpm_st_failed (test, "could not set type");
