@@ -106,7 +106,7 @@ gpm_light_sensor_get_hw (GpmLightSensor *sensor)
 		gpm_debug ("ERROR: %s", error->message);
 		g_error_free (error);
 	}
-	if (ret == FALSE) {
+	if (!ret) {
 		/* abort as the DBUS method failed */
 		gpm_warning ("GetBrightness failed!");
 		return FALSE;
@@ -114,7 +114,7 @@ gpm_light_sensor_get_hw (GpmLightSensor *sensor)
 
 	/* work out average */
 	sensor_level_hw = 0;
-	for (i = 0; i < levels->len; i++ ) {
+	for (i = 0; i < levels->len; i++) {
 		sensor_level_hw += g_array_index (levels, gint, i);
 	}
 	sensor_level_hw /= levels->len;
@@ -207,22 +207,6 @@ gpm_light_sensor_get_relative (GpmLightSensor *sensor,
 	return TRUE;
 }
 
-/**
- * gpm_light_sensor_constructor:
- **/
-static GObject *
-gpm_light_sensor_constructor (GType		  type,
-			      guint		  n_construct_properties,
-			      GObjectConstructParam *construct_properties)
-{
-	GpmLightSensor      *sensor;
-	GpmLightSensorClass *klass;
-	klass = GPM_LIGHT_SENSOR_CLASS (g_type_class_peek (GPM_TYPE_LIGHT_SENSOR));
-	sensor = GPM_LIGHT_SENSOR (G_OBJECT_CLASS (gpm_light_sensor_parent_class)->constructor
-			      		     (type, n_construct_properties, construct_properties));
-	return G_OBJECT (sensor);
-}
-
 /**
  * gpm_light_sensor_finalize:
  **/
@@ -251,7 +235,6 @@ gpm_light_sensor_class_init (GpmLightSensorClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	object_class->finalize	   = gpm_light_sensor_finalize;
-	object_class->constructor  = gpm_light_sensor_constructor;
 
 	signals [SENSOR_CHANGED] =
 		g_signal_new ("sensor-changed",
@@ -304,12 +287,12 @@ gpm_light_sensor_poll_cb (gpointer userdata)
 		return TRUE;
 	}
 
-	if (sensor->priv->has_sensor == TRUE) {
+	if (sensor->priv->has_sensor) {
 		/* fairly slow */
 		ret = gpm_light_sensor_get_hw (sensor);
 
 		/* this could fail if hal refuses us */
-		if (ret == TRUE) {
+		if (ret) {
 			gpm_light_sensor_get_absolute (sensor, &new);
 			gpm_debug ("brightness = %i, %i", sensor->priv->current_hw, new);
 			g_signal_emit (sensor, signals [SENSOR_CHANGED], 0, new);
@@ -372,7 +355,7 @@ gpm_light_sensor_init (GpmLightSensor *sensor)
 	hal_gmanager_free_capability (names);
 
 	/* connect to the devices */
-	if (sensor->priv->has_sensor == TRUE) {
+	if (sensor->priv->has_sensor) {
 		gpm_debug ("Using proper brightness sensor");
 		/* get a managed proxy */
 		sensor->priv->gproxy = dbus_proxy_new ();
@@ -394,7 +377,7 @@ gpm_light_sensor_init (GpmLightSensor *sensor)
 	}
 
 	/* do we have a info source? */
-	if (sensor->priv->has_sensor == TRUE) {
+	if (sensor->priv->has_sensor) {
 		gpm_debug ("current brightness is %i%%", sensor->priv->current_hw);
 
 		/* get poll timeout */
