@@ -104,7 +104,7 @@ gpm_notify_create (GpmNotify 	 *notify,
 	}
 
 	if (notify->priv->status_icon != NULL &&
-	    gtk_status_icon_get_visible (notify->priv->status_icon) == TRUE) {
+	    gtk_status_icon_get_visible (notify->priv->status_icon)) {
 		notify->priv->libnotify = notify_notification_new_with_status_icon (title, content,
 										    msgicon,
 										    notify->priv->status_icon);
@@ -135,7 +135,7 @@ gpm_notify_show (GpmNotify *notify)
 {
 	gboolean ret;
 	ret = notify_notification_show (notify->priv->libnotify, NULL);
-	if (ret == FALSE) {
+	if (!ret) {
 		gpm_warning ("failed to send notification");
 	}
 	return ret;
@@ -232,7 +232,7 @@ gpm_notify_display (GpmNotify 	 *notify,
 						     "<span size='larger'><b>%s</b></span>",
 						     GPM_NAME);
 
-	gtk_message_dialog_format_secondary_markup (GTK_MESSAGE_DIALOG (dialog), content);
+	gtk_message_dialog_format_secondary_markup (GTK_MESSAGE_DIALOG (dialog), "%s", content);
 
 	g_signal_connect_swapped (dialog,
 				  "response",
@@ -280,7 +280,7 @@ ac_adapter_changed_cb (GpmAcAdapter *ac_adapter,
 {
 	/* for where we add back the ac_adapter before the "AC Power unplugged"
 	 * message times out. */
-	if (on_ac == TRUE) {
+	if (on_ac) {
 		gpm_debug ("clearing notify due ac being present");
 		gpm_notify_cancel (notify);
 	}
@@ -324,7 +324,7 @@ notify_general_clicked_cb (NotifyNotification *libnotify,
 		ret = gdk_spawn_command_line_on_screen (gscreen, cmdline, &error);
 		g_free (cmdline);
 
-		if (ret == TRUE)
+		if (ret)
 			return;
 
 		g_error_free (error);
@@ -334,7 +334,7 @@ notify_general_clicked_cb (NotifyNotification *libnotify,
 		ret = gdk_spawn_command_line_on_screen (gscreen, cmdline, &error);
 		g_free (cmdline);
 
-		if (ret == FALSE) {
+		if (!ret) {
 			error_dialog = gtk_message_dialog_new ( NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_INFO, GTK_BUTTONS_OK, "Failed to show url %s", error->message); 
 			gtk_dialog_run (GTK_DIALOG (error_dialog));
 			g_error_free (error);
@@ -580,7 +580,7 @@ gpm_notify_sleep_failed (GpmNotify *notify, gboolean hibernate)
 	const gchar *icon;
 
 	title = _("Sleep Problem");
-	if (hibernate == TRUE) {
+	if (hibernate) {
 		msg = _("Your computer failed to hibernate.\nCheck the help file for common problems.");
 		icon = GPM_STOCK_HIBERNATE;
 	} else {
@@ -618,22 +618,6 @@ gpm_notify_sleep_failed (GpmNotify *notify, gboolean hibernate)
 	return TRUE;
 }
 
-/**
- * gpm_notify_constructor:
- **/
-static GObject *
-gpm_notify_constructor (GType		  type,
-			guint		  n_construct_properties,
-			GObjectConstructParam *construct_properties)
-{
-	GpmNotify      *notify;
-	GpmNotifyClass *klass;
-	klass = GPM_NOTIFY_CLASS (g_type_class_peek (GPM_TYPE_NOTIFY));
-	notify = GPM_NOTIFY (G_OBJECT_CLASS (gpm_notify_parent_class)->constructor
-			     (type, n_construct_properties, construct_properties));
-	return G_OBJECT (notify);
-}
-
 /**
  * gpm_notify_finalize:
  **/
@@ -667,7 +651,6 @@ gpm_notify_class_init (GpmNotifyClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	object_class->finalize	   = gpm_notify_finalize;
-	object_class->constructor  = gpm_notify_constructor;
 
 	g_type_class_add_private (klass, sizeof (GpmNotifyPrivate));
 }
